#ifndef __RGIG_H__
#define __RGIG_H__
double gig_gfn(const double y, const double m, const double beta, const double lambda);
double rinvgauss(const double mu, const double lambda);
double rgig(const double lambda, const double chi, const double psi);
#endif
